@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI Utilities
 
-our $VERSION = '0.1100';
+our $VERSION = '0.1101';
 
 use strict;
 use warnings;
@@ -257,7 +257,7 @@ MIDI::Util - MIDI Utilities
 
 =head1 VERSION
 
-version 0.1100
+version 0.1101
 
 =head1 SYNOPSIS
 
@@ -266,7 +266,7 @@ version 0.1100
   my $dump = midi_dump('volume'); # length, etc.
   print Dumper $dump;
 
-  my $size = dura_size('dqn');
+  my $size = dura_size('dqn'); # 1.5
 
   my $score = setup_score( bpm => 120, etc => '...', );
 
@@ -359,10 +359,10 @@ L<MIDI::Simple>, and L<MIDI::Event> internal lists:
 
 =head2 reverse_dump
 
-  %by_value = reverse_dump($name);
-  %by_value = reverse_dump($name, $precision); # for name = length
+  $by_value = reverse_dump($name);
+  $by_value = reverse_dump($name, $precision); # for name = length
 
-Return the reversed hash from the B<midi_dump> routine.
+Return the reversed hashref from the B<midi_dump> routine hashes section.
 
 =head2 midi_format
 
@@ -371,6 +371,9 @@ Return the reversed hash from the B<midi_dump> routine.
 Change sharp C<#> and flat C<b>, in the list of named notes, to the
 L<MIDI::Simple> C<s> and C<f> respectively.
 
+Also change accidentals and double-accidentals into their note
+equivalents, e.g. C<Cb> to C<B>, C<C##> to C<D>, etc.
+
 =head2 set_time_signature
 
   set_time_signature( $score, $signature );
@@ -398,6 +401,8 @@ Return the B<score> ticks.
 
 The F<t/01-functions.t> test file and F<eg/*> in this distribution
 
+L<Exporter>
+
 L<MIDI>
 
 L<MIDI::Simple>
